@@ -10,7 +10,7 @@ use Scalar::Util qw/blessed/;
 
 use vars qw($DEBUG $CACHE);
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 our %searches = (
 	cities                              => 'cities?',
@@ -32,6 +32,7 @@ our %searches = (
 	wikipedia_search                    => 'wikipediaSearch?',
 	get                                 => 'get?',
 	hierarchy                           => 'hierarchy?',
+	children                            => 'children?',
 	);
 
 #   r   = required
@@ -197,6 +198,11 @@ our %valid_parameters = (
 		username  => 'r',
 		style     => 'o',
 		},
+	children => {
+		geonameId => 'r',
+		username  => 'r',
+		style     => 'o',
+		},
 	);
 
 sub new {
@@ -383,7 +389,11 @@ sub _do_search {
 			}
 		}
 
-	carp "Invalid mime type [$mime_type]. Maybe you aren't connected.";
+	if($mime_type eq 'text/plain') {
+		carp 'Invalid mime type [text/plain]. ', $response->content();
+	} else {
+		carp "Invalid mime type [$mime_type]. Maybe you aren't connected.";
+	}
 
 	return [];
 	}
@@ -816,6 +826,18 @@ B<geonamesId> must be supplied to this method. B<style> is optional.
 For a thorough description of the arguments, see
 L<http://www.geonames.org/export/place-hierarchy.html#hierarchy>
 
+=item children(arg => $arg)
+
+Returns the children (admin divisions and populated places) for a given geonameId.
+
+    geonameId => $geonameId
+    style     => $style (Not documented, but seems to be respected)
+
+B<geonamesId> must be supplied to this method. B<style> is optional.
+
+For a thorough description of the arguments, see
+L<https://www.geonames.org/export/place-hierarchy.html>
+
 =back
 
 =head1 RETURNED DATASTRUCTURE
@@ -870,7 +892,13 @@ encoded. So make sure that strings are encoded/decoded based on the
 correct encoding.
 
 Please report any bugs found or feature requests through GitHub issues
-L<https://github.com/briandfoy/geo-geonames/issues>
+L<https://github.com/nigelhorne/Geo-GeoNames/issues>.
+or
+C<bug-geo-geonamnes at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-GeoNames>.
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
 =head1 SEE ALSO
 
@@ -885,18 +913,21 @@ L<https://github.com/briandfoy/geo-geonames/issues>
 =head1 SOURCE AVAILABILITY
 
 The source code for this module is available from Github
-at L<https://github.com/briandfoy/geo-geonames>
+at L<https://github.com/nigelhorne/Geo-GeoNames>.
 
 =head1 AUTHOR
 
 Per Henrik Johansen, C<< <per.henrik.johansen@gmail.com> >>.
 
-Currently maintained by brian d foy, C<< <brian.d.foy@gmail.com> >>
+Previously maintained by brian d foy, C<< <brian.d.foy@gmail.com> >>
 and Nicolas Mendoza, C<< <mendoza@pvv.ntnu.no> >>
 
+Maintained by Nigel Horne, C<< <njh at bandsman.co.uk> >>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2008 by Per Henrik Johansen
+Copyright © 2007-2021 by Per Henrik Johansen
+Copyright © 2022 by Nigel Horne
 
 This library is available under the Artistic License 2.0.
 
